import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.io.File;
import java.util.Collections;
import java.util.Comparator;

/**
 * Class that encapsulates a list of word frequency objects.
 *   @author Dave Reed
 *   @version 9/3/13
 */
public class WordFreqList {
    private ArrayList<Word> words;
    private ArrayList<String> ignoreWords;
    private int maxSoFar = -1;
    
    public WordFreqList() {
        this.words = new ArrayList<Word>();
        this.ignoreWords = new ArrayList<String>();
    }
    
    public WordFreqList(String ignoreFileName) {
        this();
        try {
            Scanner ignoreFile = new Scanner(new File(ignoreFileName));
            while (ignoreFile.hasNext()) {
                ignoreWords.add(Utils.stripWord(ignoreFile.next().toLowerCase()));
            }
            ignoreFile.close();
        }
        catch (java.io.FileNotFoundException e) {
            System.out.println("FILE NOT FOUND");
        }
    }
    
    public void add(String newWord) {
        this.add(newWord, 1);
    }
    
    public void add(String newWord, int count) {
        String strippedWord = Utils.stripWord(newWord.toLowerCase());
        if (strippedWord.length() > 0 && !ignoreWords.contains(strippedWord)) {
            int index = Utils.findWord(strippedWord, words);
            if (index >= 0) {
                for (int i = 0; i < count; i++) {
                    words.get(index).increment();
                }
            }
            else {
                words.add(new Word(strippedWord, count));
            }
            this.maxSoFar = Math.max(this.maxSoFar, this.getFrequency(strippedWord));
        }      
    }
    
    public int getFrequency(String word) {
        String strippedWord = Utils.stripWord(word.toLowerCase());
        int index = Utils.findWord(strippedWord, words);
        if (index >= 0) {
            return this.words.get(index).getFrequency();
        }
        else {
            return 0;
        }
    }
    
    public int getMax() {
        return this.maxSoFar;
    }
    
    public List<Word> asListByFreq() {
        Collections.sort(this.words, Word.FreqComparator);
        return this.words;
    }
    
    public List<Word> asListByAlpha() {
        Collections.sort(this.words, Word.AlphaComparator);
        return this.words;
    }
}
